@@ -165,16 +165,16 @@ if __name__ == '__main__':  # pragma: no cover
 
     parser = argparse.ArgumentParser()
     parser.add_argument('arg', metavar='PATH | USER | QUERY')
-    parser.add_argument('-B', '--base', default='http://archive.org')
-    parser.add_argument('-b', '--bookmarks', action='store_true')
+    parser.add_argument('-b', '--base', default='http://archive.org')
+    parser.add_argument('-B', '--bookmarks', action='store_true')
     parser.add_argument('-d', '--debug', action='store_true')
     parser.add_argument('-e', '--encoding', default=sys.getdefaultencoding())
-    parser.add_argument('-f', '--fields', nargs='+')
+    parser.add_argument('-F', '--fields', nargs='+')
     parser.add_argument('-i', '--indent', type=int, default=2)
     parser.add_argument('-q', '--query', action='store_true')
     parser.add_argument('-r', '--rows', type=int)
-    parser.add_argument('-s', '--sort', nargs='+')
-    parser.add_argument('-S', '--start', type=int)
+    parser.add_argument('-s', '--start', type=int)
+    parser.add_argument('-S', '--sort', nargs='+')
     parser.add_argument('-t', '--timeout', type=float)
     args = parser.parse_args()
 
