@@ -34,7 +34,7 @@ class InternetArchiveLibraryProvider(backend.LibraryProvider):
             uri=uriunsplit([backend.SCHEME, None, '/', None, None]),
             name=self.config['browse_label']
         )
-        self.search_terms = self.backend.client.query_string({
+        self.search_query = self.backend.client.query_string({
             'collection': self.config['collections'],
             '-collection': self.config['excludes'],
             'mediatype':  self.config['mediatypes'],
@@ -49,11 +49,11 @@ class InternetArchiveLibraryProvider(backend.LibraryProvider):
         return self.backend.config[self.backend.SCHEME]
 
     def parse_uri(self, uri):
-        uriparts = urisplit(uri)
-        return (uriparts.userinfo, uriparts.path, uriparts.fragment)
+        parts = urisplit(uri)
+        return (parts.userinfo, parts.path, parts.fragment)
 
     def get_bookmarks_uri(self, username):
-        authority = username + '@archive.org'
+        authority = '%s@archive.org' % username
         return uriunsplit([self.backend.SCHEME, authority, '/', None, None])
 
     def get_item_uri(self, identifier):
@@ -99,19 +99,15 @@ class InternetArchiveLibraryProvider(backend.LibraryProvider):
             return []
 
     def find_exact(self, query=None, uris=None):
-        if not query:
-            return None
         try:
-            return self._search(Query(query, True))
+            return self._search(Query(query, True) if query else None)
         except Exception as e:
             logger.error('Error searching the Internet Archive: %s', e)
             return None
 
     def search(self, query=None, uris=None):
-        if not query:
-            return None
         try:
-            return self._search(Query(query, False))
+            return self._search(Query(query, False) if query else None)
         except Exception as e:
             logger.error('Error searching the Internet Archive: %s', e)
             return None
@@ -172,7 +168,7 @@ class InternetArchiveLibraryProvider(backend.LibraryProvider):
                 'format': self.config['formats'],
             }, group='OR'),
             fields=BROWSE_FIELDS,
-            sort=(self.config['sort_order'],),
+            sort=(self.config['browse_order'],),
             rows=self.config['browse_limit']
         )
         return [self._doc_to_ref(doc) for doc in result]
@@ -213,17 +209,22 @@ class InternetArchiveLibraryProvider(backend.LibraryProvider):
         )
 
     def _search(self, query):
-        result = self.backend.client.search(
-            self.search_terms + ' AND ' + self.backend.client.query_string({
+        if query:
+            qs = self.search_query + ' ' + self.backend.client.query_string({
                 QUERY_MAP[k]: query[k] for k in query if k in QUERY_MAP
-            }, group='AND'),
+            })
+        else:
+            qs = self.search_query
+        result = self.backend.client.search(
+            qs,
             fields=SEARCH_FIELDS,
+            sort=(self.config['search_order'],),
             rows=self.config['search_limit']
         )
         albums = []
         for i, doc in enumerate(result):
             album = self._doc_to_album(doc)
-            if query.match(album):
+            if not query or query.match(album):
                 albums.append(album)
             else:
                 logger.debug('Removing #%d from search result: %r', i, doc)
